@@ -152,12 +152,13 @@ sub PluginFunction {
     }
 
     my $PluginObject   = $Self->{Plugins}->{ $Param{PluginKey} }->{Object};
+    my $PluginModule   = $Self->{Plugins}->{ $Param{PluginKey} }->{Module};
     my $PluginFunction = $Param{PluginFunction};
 
-    if ( $MainObject->Require( $PluginObject, Silent => 1 ) ) {
+    if ( !$MainObject->Require( $PluginModule, Silent => 1 ) ) {
         $LogObject->Log(
             Priority => 'error',
-            Message  => "Sorry, can't load $PluginObject!",
+            Message  => "Sorry, can't load $PluginModule!",
         );
         return;
     }
